==> atlassian_connect_host-0.3.3+2.tar.gz: lib/src/descriptor/descriptor_model.dart <==
library ac_dart.descriptor_model;

import 'package:constrain/constrain.dart';
import 'dart:core' hide Pattern;
import 'package:uri/uri.dart';
import 'package:option/option.dart';
//import 'package:zengen/zengen.dart';

//@Value()
//@EqualsAndHashCode()
class I18nProperty {

  @NotNull()
  final String value;

  final String i18n;

  I18nProperty({this.value, this.i18n});
  I18nProperty.fromJson(Map json) : value = json['value'], i18n = json['i18n'];

  Map toJson() => {
    'value': value,
    'i18n': i18n
  };
}

abstract class Module {
  
}

abstract class ModuleList {
  Map toJson();
}

class CoreModuleList implements ModuleList {
  final List<WebItem> webItems;
  final Page configurePage;

  CoreModuleList({ this.webItems: const [], this.configurePage });

  CoreModuleList.fromJson(Map json)
      : this(
          webItems: _fromJsonList(json['webItems'], 
              (wi) => new WebItem.fromJson(wi)),
          configurePage: new Page.fromJson(json['configurePage'])
        );

  Map toJson() => {
    'webItems': _toJsonList(webItems),
    'configurePage': configurePage != null ? configurePage.toJson() : null
  };
}

abstract class NamedModule implements Module {
  @NotNull()
  final I18nProperty name;
  
  NamedModule(this.name);
  NamedModule.fromJson(Map json) : name = new I18nProperty.fromJson(json['name']);

  Map toJson() => {
    'name': name.toJson()
  };
}

abstract class KeyedModule extends NamedModule {
  @NotNull()
  @Pattern(r'^[a-zA-Z0-9-]+$', isRegExp: true)
  final String key;
  
  KeyedModule(this.key, I18nProperty name) : super(name);
  KeyedModule.fromJson(Map json) : key = json['key'], super.fromJson(json);

  Map toJson() => super.toJson()..addAll({
    'key': key
  });
}

abstract class Condition {
  factory Condition.fromJson(Map json) {}
  
  Map toJson() => {};
}

abstract class ConditionalModule extends KeyedModule {
  @NotNull()
  final List<Condition> conditions;
  
  ConditionalModule(String key, I18nProperty name, this.conditions) 
      : super(key, name);
  
  ConditionalModule.fromJson(Map json) 
      : conditions = _fromJsonList(json['conditions'], 
          (j) => new Condition.fromJson(j)), 
        super.fromJson(json);

  Map toJson() => super.toJson()..addAll({
    'conditions': _toJsonList(conditions)
  });
}


abstract class BasicWebLink extends ConditionalModule {
  @NotNull()
  final UriTemplate url;
  
  final String location;

  @NotNull()
  final int weight;
    
  BasicWebLink(String key, I18nProperty name, List<Condition> conditions,
          UriTemplate url, String urlStr, this.location, this.weight)
    : this.url = _uriTemplate(url, urlStr),
      super(key, name, conditions);
  
  BasicWebLink.fromJson(Map json) 
      : url = new UriTemplate(json['url']),
        location = json['location'],
        weight = json['weight'],
        super.fromJson(json);
  
  Map toJson() => super.toJson()..addAll({
    'url': url.template,
    'location': location,
    'weight' : weight
  });


}

class WebItem extends BasicWebLink {
  
  @NotNull()
  String get location => super.location;
  
  
  WebItem({String key, I18nProperty name, List<Condition> conditions: const [],
          UriTemplate url, String urlStr, String location, int weight: 100})
    : super(key, name, conditions, url, urlStr, location, weight);
  
  WebItem.fromJson(Map json) 
      : super.fromJson(json);
}

class Page extends BasicWebLink {
  
  Page({String key, I18nProperty name, List<Condition> conditions: const [],
          UriTemplate url, String urlStr, String location, int weight: 100})
    : super(key, name, conditions, url, urlStr, location, weight);
  
  Page.fromJson(Map json) 
      : super.fromJson(json);
}


class AuthenticationType {
  final String _literal;
  
  const AuthenticationType._internal(this._literal);
  
  static const AuthenticationType NONE = const AuthenticationType._internal('NONE');  
  static const AuthenticationType JWT = const AuthenticationType._internal('JWT');
  
  static final Map<String, AuthenticationType> _literalMap = {
    NONE._literal: NONE,
    JWT._literal: JWT
  };
  
  String toString() => _literal;
  
  static Option<AuthenticationType> lookup(String literal) => 
      new Option(_literalMap[literal]);
  
}

class Authentication {
  @NotNull()
  final AuthenticationType type;
  
  Authentication({ this.type: AuthenticationType.JWT });
  
  Authentication.fromJson(Map json) 
      : type = AuthenticationType.lookup(json['type']).getOrElse(AuthenticationType.JWT);
  
  Map toJson() => {
    'type': type.toString()
  };
}

class Lifecycle {
  final Uri installed;
  
  Lifecycle({ Uri installed, String installedStr })
      : this.installed = _uri(installed, installedStr);
  
  Lifecycle.fromJson(Map json)
      : installed = _uri(null, json['lifecycle']);
  
  Map toJson() => {
    'installed': installed.toString()
  };
      
}

abstract class ConnectAddon<M extends ModuleList>  {
  @NotNull()
  @Pattern(r'^[a-zA-Z0-9-]+$', isRegExp: true)
  final String key;

  final String name;
  
  @NotNull()
  final Uri baseUrl;

  @NotNull()
  final M modules;
  
  @NotNull()
  final Authentication authentication; 
  
  final Lifecycle lifecycle;
  
//  scopes

  ConnectAddon({ this.key, this.name, this.modules, Uri baseUrl, String baseUrlStr,
    this.authentication, this.lifecycle })
      : this.baseUrl = _uri(baseUrl, baseUrlStr);
  ConnectAddon.fromJson(Map json, M modulesFromJson(Map j))
    : key = json['key'],
      name = json['name'],
      baseUrl = _uri(null, json['baseUrl']),
      modules = modulesFromJson(json['modules']),
      authentication = new Authentication.fromJson(json['authentication']),
      lifecycle = json['lifecycle'] != null ? 
          new Lifecycle.fromJson(json['lifecycle']) : null;

  Map toJson() => _cleanJson({
      'key': key != null ? key: null,
      'name': name != null ? name : null,
      'baseUrl': baseUrl != null ? baseUrl.toString() : null,
      'modules': modules != null ? modules.toJson() : null,
      'authentication': authentication != null ? authentication.toJson() : null,
      'lifecycle': lifecycle != null ? lifecycle.toJson() : null          
  });
}

class ProductlessConnectAddon extends ConnectAddon<CoreModuleList> {
  ProductlessConnectAddon({ String key, String name, CoreModuleList modules,
    Uri baseUrl, String baseUrlStr, Authentication authentication,
    Lifecycle lifecycle})
      : super(key: key, name: name, modules: modules,
          baseUrl: baseUrl, baseUrlStr: baseUrlStr,
          authentication: authentication, lifecycle: lifecycle);

  ProductlessConnectAddon.fromJson(Map json)
      : super.fromJson(json, (Map j) => new CoreModuleList.fromJson(j));

  Map toJson() => super.toJson();
}


_fromJsonList(List jl, mapping(e)) =>
    jl != null ? jl.map(mapping).toList(growable: false) : [];

Iterable _toJsonList(List l) =>
    l != null ? l.map((e) => e.toJson()).toList(growable: false) : null;

UriTemplate _uriTemplate(UriTemplate uri, String uriStr) =>
    uri != null ? uri : uriStr != null ? new UriTemplate(uriStr) : null;

Uri _uri(Uri uri, String uriStr) =>
    uri != null ? uri : uriStr != null ? Uri.parse(uriStr) : null;
    
Map _cleanJson(Map j) {
  final cleaned = {};
  j.forEach((k, v) {
    if (v != null) {
      if (v is Map) {
        cleaned[k] = _cleanJson(v);
      }
      else if (v is Iterable) {
        final l = v.expand(_cleanJsonIterable).toList(growable:false);
        if (l.isNotEmpty) {
          cleaned[k] = l;
        }
      }
      else {
        cleaned[k] = v;        
      }
    }
  });
  return cleaned;
}


Iterable _cleanJsonIterable(j) {
  if (j == null) {
    return [];
  }

  final result = j is Map ? _cleanJson(j) : j; 
  return [result];
}

==> atlassian_connect_host-0.3.4.tar.gz: lib/src/descriptor/descriptor_model.dart <==
library ac_dart.descriptor_model;

import 'package:constrain/constrain.dart';
import 'dart:core' hide Pattern;
import 'package:uri/uri.dart';
import 'package:option/option.dart';
//import 'package:zengen/zengen.dart';

//@Value()
//@EqualsAndHashCode()
class I18nProperty {

  @NotNull()
  final String value;

  final String i18n;

  I18nProperty({this.value, this.i18n});
  I18nProperty.fromJson(Map json) : value = json['value'], i18n = json['i18n'];

  Map toJson() => {
    'value': value,
    'i18n': i18n
  };
}

abstract class Module {
  
}

abstract class ModuleList {
  Map toJson();
}

class CoreModuleList implements ModuleList {
  final List<WebItem> webItems;
  final Page configurePage;

  CoreModuleList({ this.webItems: const [], this.configurePage });

  CoreModuleList.fromJson(Map json)
      : this(
          webItems: _fromJsonList(json['webItems'], 
              (wi) => new WebItem.fromJson(wi)),
          configurePage: new Page.fromJson(json['configurePage'])
        );

  Map toJson() => {
    'webItems': _toJsonList(webItems),
    'configurePage': configurePage != null ? configurePage.toJson() : null
  };
}

abstract class NamedModule implements Module {
  @NotNull()
  final I18nProperty name;
  
  NamedModule(this.name);
  NamedModule.fromJson(Map json) : name = new I18nProperty.fromJson(json['name']);

  Map toJson() => {
    'name': name.toJson()
  };
}

abstract class KeyedModule extends NamedModule {
  @NotNull()
  @Pattern(r'^[a-zA-Z0-9-]+$', isRegExp: true)
  final String key;
  
  KeyedModule(this.key, I18nProperty name) : super(name);
  KeyedModule.fromJson(Map json) : key = json['key'], super.fromJson(json);

  Map toJson() => super.toJson()..addAll({
    'key': key
  });
}

abstract class Condition {
  factory Condition.fromJson(Map json) {}
  
  Map toJson() => {};
}

abstract class ConditionalModule extends KeyedModule {
  @NotNull()
  final List<Condition> conditions;
  
  ConditionalModule(String key, I18nProperty name, this.conditions) 
      : super(key, name);
  
  ConditionalModule.fromJson(Map json) 
      : conditions = _fromJsonList(json['conditions'], 
          (j) => new Condition.fromJson(j)), 
        super.fromJson(json);

  Map toJson() => super.toJson()..addAll({
    'conditions': _toJsonList(conditions)
  });
}


abstract class BasicWebLink extends ConditionalModule {
  @NotNull()
  final UriTemplate url;
  
  final String location;

  @NotNull()
  final int weight;
    
  BasicWebLink(String key, I18nProperty name, List<Condition> conditions,
          UriTemplate url, String urlStr, this.location, this.weight)
    : this.url = _uriTemplate(url, urlStr),
      super(key, name, conditions);
  
  BasicWebLink.fromJson(Map json) 
      : url = new UriTemplate(json['url']),
        location = json['location'],
        weight = json['weight'],
        super.fromJson(json);
  
  Map toJson() => super.toJson()..addAll({
    'url': url.template,
    'location': location,
    'weight' : weight
  });


}

class WebItem extends BasicWebLink {
  
  @NotNull()
  String get location => super.location;
  
  
  WebItem({String key, I18nProperty name, List<Condition> conditions: const [],
          UriTemplate url, String urlStr, String location, int weight: 100})
    : super(key, name, conditions, url, urlStr, location, weight);
  
  WebItem.fromJson(Map json) 
      : super.fromJson(json);
}

class Page extends BasicWebLink {
  
  Page({String key, I18nProperty name, List<Condition> conditions: const [],
          UriTemplate url, String urlStr, String location, int weight: 100})
    : super(key, name, conditions, url, urlStr, location, weight);
  
  Page.fromJson(Map json) 
      : super.fromJson(json);
}


class AuthenticationType {
  final String _literal;
  
  const AuthenticationType._internal(this._literal);
  
  static const AuthenticationType NONE = const AuthenticationType._internal('NONE');  
  static const AuthenticationType JWT = const AuthenticationType._internal('JWT');
  
  static final Map<String, AuthenticationType> _literalMap = {
    NONE._literal: NONE,
    JWT._literal: JWT
  };
  
  String toString() => _literal;
  
  static Option<AuthenticationType> lookup(String literal) => 
      new Option(_literalMap[literal]);
  
}

class Authentication {
  @NotNull()
  final AuthenticationType type;
  
  Authentication({ this.type: AuthenticationType.JWT });
  
  Authentication.fromJson(Map json) 
      : type = AuthenticationType.lookup(json['type']).getOrElse(AuthenticationType.JWT);
  
  Map toJson() => {
    'type': type.toString()
  };
}

class Lifecycle {
  final Uri installed;
  
  Lifecycle({ Uri installed, String installedStr })
      : this.installed = _uri(installed, installedStr);
  
  Lifecycle.fromJson(Map json)
      : installed = _uri(null, json['lifecycle']);
  
  Map toJson() => {
    'installed': installed.toString()
  };
      
}

abstract class ConnectAddon<M extends ModuleList>  {
  @NotNull()
  @Pattern(r'^[a-zA-Z0-9-]+$', isRegExp: true)
  final String key;

  final String name;
  
  final String description;
  
  @NotNull()
  final Uri baseUrl;

  @NotNull()
  final M modules;
  
  @NotNull()
  final Authentication authentication; 
  
  final Lifecycle lifecycle;
  
//  scopes

  ConnectAddon({ this.key, this.name, this.description
    , this.modules, Uri baseUrl, String baseUrlStr,
    this.authentication, this.lifecycle })
      : this.baseUrl = _uri(baseUrl, baseUrlStr);
  ConnectAddon.fromJson(Map json, M modulesFromJson(Map j))
    : key = json['key'],
      name = json['name'],
      description = json['description'],
      baseUrl = _uri(null, json['baseUrl']),
      modules = modulesFromJson(json['modules']),
      authentication = new Authentication.fromJson(json['authentication']),
      lifecycle = json['lifecycle'] != null ? 
          new Lifecycle.fromJson(json['lifecycle']) : null;

  Map toJson() => _cleanJson({
      'key': key != null ? key: null,
      'name': name != null ? name : null,
      'description': description != null ? description : null,
      'baseUrl': baseUrl != null ? baseUrl.toString() : null,
      'modules': modules != null ? modules.toJson() : null,
      'authentication': authentication != null ? authentication.toJson() : null,
      'lifecycle': lifecycle != null ? lifecycle.toJson() : null          
  });
}

class ProductlessConnectAddon extends ConnectAddon<CoreModuleList> {
  ProductlessConnectAddon({ String key, String name, CoreModuleList modules,
    Uri baseUrl, String baseUrlStr, Authentication authentication,
    Lifecycle lifecycle})
      : super(key: key, name: name, modules: modules,
          baseUrl: baseUrl, baseUrlStr: baseUrlStr,
          authentication: authentication, lifecycle: lifecycle);

  ProductlessConnectAddon.fromJson(Map json)
      : super.fromJson(json, (Map j) => new CoreModuleList.fromJson(j));

  Map toJson() => super.toJson();
}


_fromJsonList(List jl, mapping(e)) =>
    jl != null ? jl.map(mapping).toList(growable: false) : [];

Iterable _toJsonList(List l) =>
    l != null ? l.map((e) => e.toJson()).toList(growable: false) : null;

UriTemplate _uriTemplate(UriTemplate uri, String uriStr) =>
    uri != null ? uri : uriStr != null ? new UriTemplate(uriStr) : null;

Uri _uri(Uri uri, String uriStr) =>
    uri != null ? uri : uriStr != null ? Uri.parse(uriStr) : null;
    
Map _cleanJson(Map j) {
  final cleaned = {};
  j.forEach((k, v) {
    if (v != null) {
      if (v is Map) {
        cleaned[k] = _cleanJson(v);
      }
      else if (v is Iterable) {
        final l = v.expand(_cleanJsonIterable).toList(growable:false);
        if (l.isNotEmpty) {
          cleaned[k] = l;
        }
      }
      else {
        cleaned[k] = v;        
      }
    }
  });
  return cleaned;
}


Iterable _cleanJsonIterable(j) {
  if (j == null) {
    return [];
  }

  final result = j is Map ? _cleanJson(j) : j; 
  return [result];
}
